==> grpc-core-0.7.1-sources.jar: io/grpc/HandlerRegistry.java <==
/*
 * Copyright 2014, Google Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *    * Redistributions of source code must retain the above copyright
 * notice, this list of conditions and the following disclaimer.
 *    * Redistributions in binary form must reproduce the above
 * copyright notice, this list of conditions and the following disclaimer
 * in the documentation and/or other materials provided with the
 * distribution.
 *
 *    * Neither the name of Google Inc. nor the names of its
 * contributors may be used to endorse or promote products derived from
 * this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package io.grpc;

import javax.annotation.Nullable;
import javax.annotation.concurrent.ThreadSafe;

/**
 * Registry of services and their methods used by servers to dispatching incoming calls.
 */
@ThreadSafe
public abstract class HandlerRegistry {

  /**
   * Lookup a {@link Method} by its fully-qualified name. All names are expected to be absolute
   * paths that start with '/'.
   *
   * @param methodName to lookup {@link Method} for.
   * @return the resolved method or {@code null} if no method for that name exists.
   */
  @Nullable
  public abstract Method lookupMethod(String methodName);

  /**
   * A method belonging to a service to be exposed to remote callers.
   */
  public static final class Method {
    private final ServerServiceDefinition serviceDef;
    private final ServerMethodDefinition<?, ?> methodDef;

    public Method(ServerServiceDefinition serviceDef, ServerMethodDefinition<?, ?> methodDef) {
      this.serviceDef = serviceDef;
      this.methodDef = methodDef;
    }

    public ServerServiceDefinition getServiceDefinition() {
      return serviceDef;
    }

    public ServerMethodDefinition<?, ?> getMethodDefinition() {
      return methodDef;
    }
  }
}

==> grpc-core-0.8.0-sources.jar: io/grpc/HandlerRegistry.java <==
/*
 * Copyright 2014, Google Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *    * Redistributions of source code must retain the above copyright
 * notice, this list of conditions and the following disclaimer.
 *    * Redistributions in binary form must reproduce the above
 * copyright notice, this list of conditions and the following disclaimer
 * in the documentation and/or other materials provided with the
 * distribution.
 *
 *    * Neither the name of Google Inc. nor the names of its
 * contributors may be used to endorse or promote products derived from
 * this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package io.grpc;

import javax.annotation.Nullable;
import javax.annotation.concurrent.ThreadSafe;

/**
 * Registry of services and their methods used by servers to dispatching incoming calls.
 */
@ThreadSafe
public abstract class HandlerRegistry {

  /**
   * Lookup a {@link Method} by its fully-qualified name.
   *
   * @param methodName to lookup {@link Method} for.
   * @return the resolved method or {@code null} if no method for that name exists.
   */
  @Nullable
  public abstract Method lookupMethod(String methodName);

  /**
   * A method belonging to a service to be exposed to remote callers.
   */
  public static final class Method {
    private final ServerServiceDefinition serviceDef;
    private final ServerMethodDefinition<?, ?> methodDef;

    public Method(ServerServiceDefinition serviceDef, ServerMethodDefinition<?, ?> methodDef) {
      this.serviceDef = serviceDef;
      this.methodDef = methodDef;
    }

    public ServerServiceDefinition getServiceDefinition() {
      return serviceDef;
    }

    public ServerMethodDefinition<?, ?> getMethodDefinition() {
      return methodDef;
    }
  }
}
